#include <stdio.h>
#include <stdlib.h>

#define MAGIC_NUMBER 0x53483130
#define USAGE "[-c pixels scanlines xcenter ycenter] [-s]"

/*This program can either create interal Sherlock image format headers, or
  display header information from a Sherlock image format.

  Inputs:  argc  - number of command line arguments
	   argv  - command line arguments
  Outputs: none
  Locals:  none
  Globals: USAGE - usage message
*/
main(argc,argv)
register int argc;
register char *argv[];
{
	if(argc > 1) {
	  if(!strcmp(argv[1],"-c")) create_header(argc,argv);
	  else if(!strcmp(argv[1],"-s")) strip_header();
	       else {
		      fprintf(stderr,"usage: %s %s\n",argv[0],USAGE);
		      exit(1);
		    }
	} else display_header();

	exit(0);
}

/*Create a Sherlock internal format header and sent to stdout.

  Inputs:  argc         - number of command line arguments
	   argv         - command line arguments
  Outputs: none
  Locals:  loop         - loop through values on command line
	   value        - value to write to header
  Globals: stderr       - standard error
	   stdout       - standard output
	   MAGIC_NUMBER - magic number for Sherlock image format
	   USAGE	- usage message
*/
create_header(argc,argv)
register int argc;
register char *argv[];
{
	register int loop;
	long value;

	/*Check for proper number of command line values*/
	if(argc != 6) {
	  fprintf(stderr,"usage: %s %s\n",argv[0],USAGE);
	  exit(1);
	}

	/*Write out magic number*/
	value = MAGIC_NUMBER;
	write(fileno(stdout),(char *) &value,sizeof(value));

	/*Write out rest of values (pixels, scanlines, xcenter, ycenter)*/
	for(loop = 2;loop < argc;++loop) {
	  value = atol(argv[loop]);
	  write(fileno(stdout),(char *) &value,sizeof(value));
	}
}

/*Display the information found in a Sherlock image header.

  Inputs:  none
  Outputs: none
  Locals:  value - value found in header
  Globals: stdin - standard input
*/
display_header()
{
	long value;

	read(fileno(stdin),(char *) &value,sizeof(value));

	read(fileno(stdin),(char *) &value,sizeof(value));
	printf("Pixels    = %ld\n",value);

	read(fileno(stdin),(char *) &value,sizeof(value));
	printf("Scanlines = %ld\n",value);

	read(fileno(stdin),(char *) &value,sizeof(value));
	printf("Xcenter   = %ld\n",value);

	read(fileno(stdin),(char *) &value,sizeof(value));
	printf("Ycenter   = %ld\n",value);
}

strip_header()
{
	register long loop;
	long pixels,scanlines,value;
	unsigned char *array;

	/*Read in header*/
	read(fileno(stdin),(char *) &value,sizeof(value));
	read(fileno(stdin),(char *) &pixels,sizeof(value));
	read(fileno(stdin),(char *) &scanlines,sizeof(value));
	read(fileno(stdin),(char *) &value,sizeof(value));
	read(fileno(stdin),(char *) &value,sizeof(value));

	array = (unsigned char *) malloc(pixels);

	/*Pass through image bytes*/
	for(loop = 0;loop < scanlines;++loop) {
	  read(fileno(stdin),array,pixels);
	  write(fileno(stdout),array,pixels);
	}
}

