%{
#include <stdlib.h>
#include <string.h>
#include "grammar.h"
#include "sherlock.h"
#include "error.h"

int linenum = 1;
extern int errno;
%}
COMMENT         (#.*\n)
MATCH_STRING    ([a-zA-Z/][a-zA-Z0-9_\./]*)
NUMBER          ([0-9]+)
%%
{COMMENT}       { ++linenum; if(isbitset(BATCHFILE)) ECHO; prompt(); }
{NUMBER}        {
		  if(isbitset(BATCHFILE)) ECHO;

		  yylval.lnum = atol(yytext);
		  return(LONG);
		}
!.*		{ 
		  if(isbitset(BATCHFILE)) ECHO;

		  if((yylval.string = strdup(yytext + 1)) == NULL)
		    error(FATAL,errno);
		  else return(SHELL_ESCAPE_CMD);
		}
crop		{ if(isbitset(BATCHFILE)) ECHO; return(CROP_CMD); }
load		{ if(isbitset(BATCHFILE)) ECHO; return(LOAD_CMD); }
save		{ if(isbitset(BATCHFILE)) ECHO; return(SAVE_CMD); }
exit		{ if(isbitset(BATCHFILE)) ECHO; return(EXIT_CMD); }
run		{ if(isbitset(BATCHFILE)) ECHO; return(RUN_CMD); }
sleep		{ if(isbitset(BATCHFILE)) ECHO; return(SLEEP_CMD); }
invert		{ if(isbitset(BATCHFILE)) ECHO; return(INVERT_CMD); }
seed		{ if(isbitset(BATCHFILE)) ECHO; return(SEED_CMD); }
image		{
		  if(isbitset(BATCHFILE)) ECHO;
		  
		  yylval.inum = IMAGE;

		  return(TYPE);
		}
pattern		{
		  if(isbitset(BATCHFILE)) ECHO;
		  
		  yylval.inum = PATTERN;

		  return(TYPE);
		}
auto		{
		  if(isbitset(BATCHFILE)) ECHO;

		  yylval.inum = AUTO_INVERT;

		  return(DECISION);
		}
yes		{
		  if(isbitset(BATCHFILE)) ECHO;

		  yylval.inum = YES_INVERT;

		  return(DECISION);
		}
no		{
		  if(isbitset(BATCHFILE)) ECHO;

		  yylval.inum = NO_INVERT;

		  return(DECISION);
		}
space		{
		  if(isbitset(BATCHFILE)) ECHO;

		  yylval.inum = SPACE_DOMAIN;

		  return(ALGORITHM);
		}
frequency|freq	{
		  if(isbitset(BATCHFILE)) ECHO;

		  yylval.inum = FREQ_DOMAIN;

		  return(ALGORITHM);
		}
lps		{
		  if(isbitset(BATCHFILE)) ECHO;

		  yylval.inum = LPS;

		  return(ALGORITHM);
		}
random		{
		  if(isbitset(BATCHFILE)) ECHO;

		  yylval.inum = RANDOM;

		  return(ALGORITHM);
		}
{MATCH_STRING}  {
		  if(isbitset(BATCHFILE)) ECHO;

		  if((yylval.string = strdup(yytext)) == NULL)
		    error(FATAL,errno);
		  else return(STRING);
		}
\n              { if(isbitset(BATCHFILE)) ECHO; return('\n'); }
[ \t]		{ if(isbitset(BATCHFILE)) ECHO; }
.		{ if(isbitset(BATCHFILE)) ECHO; return(yytext[0]); }
%%

/*This function is called when lex reaches EOF.  A value of 1 is returned
  to tell lex to finish up normally.

  Inputs:  none
  Outputs: 1 - tells lex to finish normally
  Locals:  none
  Globals: none
*/
int yywrap()
{
    return(1);
}

