#include <stdio.h>
#include "sherlock.h"
#include "xvgr.h"

/*Write graph legend commands for a specific algorithm to a graph file.

  Inputs:  alg          - algorithm this legend is for
	   dataset      - number of the dataset for this algorithm's data
	   fp           - file pointer to write commands to
  Outputs: none
  Locals:  none
  Globals: FREQ_DOMAIN  - write legend commands for frequency domain correlation
	   LPS          - write legend commands for linear pixel shuffling
	   RANDOM       - write legend commands for random ordering
	   SPACE_DOMAIN - write legend commands for space domain correlation
*/
xvgr_legend(fp,dataset,alg)
register int dataset,alg;
register FILE *fp;
{
	set_color(fp,dataset);

	switch(alg) {
          case SPACE_DOMAIN:
                set_legend_string(fp,dataset,"Space Domain");
                break;
          case FREQ_DOMAIN:
                set_legend_string(fp,dataset,"Frequency Domain");
                break;
          case LPS:
                set_legend_string(fp,dataset,"Linear Pixel Shuffling");
                break;
          case RANDOM:
                set_legend_string(fp,dataset,"Random Ordering");
                break;
	}

	fputs("\n",fp);
	fflush(fp);
}

/*Write out graph commands for the XVGR graphing program.  Commands set up
  the graphing environment to make the graphs look nice.

  Inputs:  fp - file pointer to write commands to
	   ylabel - label for Y axis
  Outputs: none
  Locals:  none
  Globals: subtitle - subtitle for graph
	   title    - title for graph
	   LEGEND_X - X coordinate for graph legend
	   LEGEND_Y - Y coordinate for graph legend
*/
xvgr_commands(fp,xlabel,ylabel)
register char *xlabel,*ylabel;
register FILE *fp;
{
	if(fp) {
	  /*Set up to scale automatically*/
	  set_autoscale(fp);

	  /*Set title and subtitle*/
	  if(title) set_title(fp,title);
	  if(subtitle) set_subtitle(fp,subtitle);

	  /*Set X axis attributes (label, tick marks)*/
	  set_xaxis_label(fp,xlabel);
	  set_tick(fp,"xaxis");
	  set_xaxis_tick_label_format(fp);

	  /*Set Y axis attributes (label, tick marks)*/
	  set_yaxis_label(fp,ylabel);
	  set_tick(fp,"yaxis");
	  if(!strcmp(ylabel,"Correlation")) set_tick_format(fp);

	  /*Set legend attributes*/
	  set_legend(fp);
	  set_legend_coord(fp,"x1",LEGEND_X);
	  set_legend_coord(fp,"y1",LEGEND_Y);
	  set_legend_box(fp);
	  set_legend_box_fill(fp);
	  set_legend_box_fill_method(fp);
	  set_legend_box_fill_pattern(fp);

	  fclose(fp);
	}
}

